# `cli50`

[![Build Status](https://travis-ci.com/cs50/cli50.svg?branch=master)](https://travis-ci.org/cs50/cli50)

This is `cli50`, a command-line script that facilitates using [CS50 CLI](https://github.com/cs50/cli).
